# myFunctionAggs.R

# DateTime, if, for, define functions, aggregates, list()

# Function -> define,value,return "call"

# Define the function myAggregates()
myAggregates <- function(numbers) {
  # scope of the function
  results <- list() # Initialize in memory an empty list
  
  # Calculate several statistical results
  results$average <- mean(numbers) # average of the numbers passed to the function
  results$count <- length(numbers) # count of the numbers passed
  results$sum <- sum(numbers)
  results$min <- min(numbers)
  results$max <- max(numbers)
  
  # Validate if the range is between 0-100
  ## if statement to test a condition
  ## relational operator < > <= >=
  ## logical operator and && or || not !
  ### Even if you are testing the same variable, you MUST repeat the variable name on BOTH sides of a logical operator
  ### age <- 21
  ### age < 18 && state = "Florida"
  ### age < 18 || age > 25
  
  if ( results$min < 0 || results$max > 100 ) {
    cat("Number is not valid: min < 0 or max > 100\n")
  }
  
  # The last line of a function is the return
  return(results)
  
} # function

# Output / Program
## Data to pass to the function
list_of_numbers <- c(12, 85, 52, 105, 41, 33)

# Write all the results to a log file
## write(io) -> write to a IO
## print() -> sys.output(console) !IO using print
## cat(io,sys.output) -> sys.output(console) && IO
file_conn <- file("aggregates_results.txt", open = "w")

cat("=== Numbers in our List ===\n", file = file_conn)

# for loop to loop thru the list and display our numbers
# for (x in ys)
## x is the local variable in the for scope
## ys is your data set 
for (number in list_of_numbers) {
  
  cat(number, "\n", file = file_conn) #(int, string)
  
} # for

# call the function, pass the list and assign the return to a variable

aggregates <- myAggregates(list_of_numbers)

cat(aggregates, file = file_conn)

# Log a datetime when we ran the test
## Sys.Date class
## Date() -> get the current date now()
## Standard formatting (same as python)
### Friday February 21, 2025
### %A %B %d, %Y

# Get the current date and format
current_date <- Sys.Date()
cat(current_date, "\n", file = file_conn)
current_date_formatted <- format(current_date, "%A %B %d, %Y")
cat(current_date_formatted, file = file_conn)

# EOF myFunctionAggs.R