# plots_dataFrame.R

# You do not need to use a data frame directly for plotting. It is recommended that you use a data frame

# You want to use the data frame to be sure you have cleaned, prepped and shaped data to work with.

student_scores <- data.frame(
  name = c("Bob","Joe","Mary","Beth","Mark"),
  math_scores = c(85, 92, 45, 65, 23),
  science_scores = c(74, 99, 21, 54, 46)
) # student_scores

# print(student_scores)

# Load the plotting library ggplot2
#install.packages("ggplot2")
library(ggplot2)

# Line Plot
# x,y analysis of a series/sequence of values, commonly over a date/time series
## (dataSet, x axis, y axis)
## 1 x and either 1 or more y series
ggplot(
  data = student_scores, # data frame parameter 1
  aes(x = name)) +  # join the y axis (math and science scores)
  geom_line(aes(
    y = math_scores, group = 1, colour = "Math")) + 
  geom_line(aes(
    y = science_scores, group = 1, colour = "Science")) +
  labs(
    title = "Student Scores by Subject",
    x = "Student Name",
    y = "Scores",
    colour = "Subject"
  ) + 
  scale_colour_manual(values = c("Math" = "blue", "Science" = "red")) + 
  theme_classic()
# theme_gray, theme_bw, _light, _dark

# Bar Plot
## a singular contiguous set of data
## 1 x and 1 y series of data, identify set "where" values cross
## (data set, x, y, ...)
ggplot(
  data = student_scores, 
  aes(
    x = name, # x axis
    y = math_scores, # y axis
    fill = name
  )) + # ggplot
  geom_bar(stat = "identity") + # bar plot()
  labs(
    title = "Math Scores by Student",
    x = "Student Name",
    y = "Math Score"
  ) +
  theme_grey()

# Box Plot
## use to compare categories of data
## 1. create your categories using factors(name)
## 2. We can use ggplot with library(reshape2) and the melt(name)

# install and load the reshape2 library
#install.packages("reshape2")
library(reshape2)
## Instead of using factor and storing the categorized data in memory as a variable, we will use reshape2 melt() to shape the category for our plot
student_scores_melted <- melt(student_scores, id.vars = "name")

## Box plot
ggplot(
  data = student_scores_melted, # param 1 data set
  aes(
    x = variable,
    y = value,
    fill = variable
  )) + 
  geom_boxplot() + 
  labs(
    title = "Distribution of Scores",
    x = "Subject",
    y = "Scores"
  ) + 
  theme_light()

# Histogram
## Sample data using rnorm()
df_Histogram = data.frame(
  values = rnorm(100, mean = 50, sd = 10)
)

print(df_Histogram)

## Histogram Plot
ggplot(
  df_Histogram, # param 1 data
  aes(
    x = values, # x is my sample rnorm()
    # y is frequency, not defined here
  )) + # ggplot()
  geom_histogram(
    bins = 5,
    fill = "blue",
    colour = "black"
  ) + 
  labs(
    title = "Histogram of Values",
    x = "Values from rnorm()",
    y = "Frequency"
  ) + 
  theme_classic()
  
  


# EOF plots_dataFrame.R